:mod:`maec.bundle.behavior_reference` Module
============================================

.. module:: maec.bundle.behavior_reference

Classes
-------

.. autoclass:: BehaviorReference
	:show-inheritance:
	:members:



